@@ -12,9 +12,12 @@ class DummyOptions(KnowledgeParserOptions):
     foo : str = Field("bar", description="Dummy parameter")
 
 class DummyKnowledgeParser(KnowledgeParserBase):
-    def parse(self, source : Path, options : Dict[str,Any], bar : Bar = None):
+    def parse(self, source : Path, options : Dict[str,Any], bar : Bar):
         options = DummyOptions(**options)
+        bar.max = 1
+        bar.next()
         yield Concept(identifier=options.foo, prefLabel=options.foo)
+        bar.finish()
 
     @classmethod
     def get_schema(cls) -> Type[BaseModel]:
